#include <Adafruit_GFX.h>
#include <Adafruit_PCD8544.h>

#include "Wire.h"
#include <MPU6050_light.h>
#include <StopWatch.h>

StopWatch MyClock;


int contrast=60;
int up_button = 9;
int down_button = 3;

int up_state = 0;
int down_state = 0;

int buzzer = 2;

int VerticalMove = 1;
int x_pos = 0;
int y_pos = 0;
int SidewaysMove = 1;

int Dotx = 28;
int Doty = 14;

int xPoss[6] = {0,14,28,42,56,70};
int yPoss[6] = {0,7,14,21,28,35};

int xIndex = 0;
int yIndex = 0;

int Score = 0;

bool gameOver = false;
bool EndSound = true;
bool Start = true;


Adafruit_PCD8544 display = Adafruit_PCD8544(8,7,6,5,4);
MPU6050 mpu(Wire);

void setup() {
  
  Serial.begin(9600);
  
  Wire.begin();
  mpu.begin();
  Serial.println(F("Calculating gyro offset, do not move MPU6050"));
  delay(1000);
  mpu.calcGyroOffsets();
  Serial.println("Done!\n");


  pinMode(up_button, INPUT_PULLUP);
  pinMode(down_button, INPUT_PULLUP);
  pinMode(buzzer, OUTPUT);
  display.begin();      
  display.setContrast(contrast); //Set contrast to 60
  display.clearDisplay(); 
  display.display();   
}

void loop() {

  if(MyClock.elapsed() >= 5000)
  {
    gameOver = true;
    if(EndSound == true)
    {
      tone(buzzer, 600);
      delay(200);
      noTone(buzzer);
      tone(buzzer, 570);
      delay(200);
      noTone(buzzer);
      tone(buzzer, 500);
      delay(200);
      noTone(buzzer);
      EndSound = false;
    }
    
    MyClock.stop();
  }

  if(gameOver == true)
  {
    GameOverScreen();
  }
  else 
  {
    if(Start == true)
    {
      StartScreen();
      Start = false;
    }
    drawGame();
  }
 }

 void StartScreen()
 {
    display.setTextSize(1);
    display.clearDisplay();
    display.setTextColor(BLACK, WHITE);
    display.setCursor(6, 5);
    display.setTextSize(1);
    display.print("DIAMOND DASH");
    display.setCursor(0, 20);
    display.print("Collect diamonds before time runs out !");
    display.display();
    delay(8000);
 }
  
  void drawGame()
  {  
    PlayerposCheck();
    XCheck();
  }

  void PlayerposCheck()
  {
    up_state = digitalRead(up_button);
    down_state = digitalRead(down_button);
  
  
    if (up_state == 0)
    {
        if(VerticalMove < 6)
      {
        VerticalMove += 1;
      }
    }

    if(down_state == 0)
    {
      if(VerticalMove > 1)
      {
        VerticalMove -= 1;
      }
    }
    display.clearDisplay();
    drawPlayer();
 }

 void XCheck()
 {
  mpu.update();
  //Serial.println(mpu.getAngleX());
  if(mpu.getAngleX() > 60)
  {
    x_pos = 0;
  }
  else if(mpu.getAngleX() > 40)
  {
    x_pos = 14;
  }
  else if(mpu.getAngleX() > 20)
  {
    x_pos = 28;
  }
  else if(mpu.getAngleX() > 0)
  {
    x_pos = 42;
  }
  else if(mpu.getAngleX() > -20)
  {
    x_pos = 56;
  }
  else if(mpu.getAngleX() > -40)
  {
    x_pos = 70;
  }
  
 }

  void drawPlayer()
  {
    if(VerticalMove == 1)
    {
      display.setCursor(x_pos,35);
      y_pos = 35;
    }
    else if(VerticalMove == 2)
    {
      display.setCursor(x_pos,28);
      y_pos = 28;
    }
    else if(VerticalMove == 3)
    {
      display.setCursor(x_pos,21);
      y_pos = 21;
    }
    else if(VerticalMove == 4)
    {
      display.setCursor(x_pos,14);
      y_pos = 14;
    }
    else if(VerticalMove == 5)
    {
      display.setCursor(x_pos,7);
      y_pos = 7;
    }
    else if(VerticalMove == 6)
    {
      display.setCursor(x_pos,0);
      y_pos = 0;
    }



    display.setTextSize(2);
    display.write(2);
    display.display();

    if(Dotx != x_pos or Doty != y_pos)
    {
      display.setCursor(Dotx, Doty);
      display.setTextSize(2);
      display.write(4);
      display.display();
    }
    else if(Dotx == x_pos and Doty == y_pos)
    {
      MyClock.stop();
      MyClock.reset();
      tone(buzzer, 600);
      delay(250);
      noTone(buzzer);
      Score = Score + 1;
      ChangeDotPos();
    }

    delay(150);
    
  }

  void ChangeDotPos()
  {
    xIndex = random(0,6);
    yIndex = random(0,6);

    Dotx = xPoss[xIndex];
    Doty = yPoss[yIndex];
    Serial.println(Dotx);
    Serial.println(Doty);

    display.setCursor(Dotx, Doty);
    display.setTextSize(2);
    display.write(4);
    display.display();
    MyClock.start();
    
  }

  void GameOverScreen()
  {
    display.setTextSize(1);
    display.clearDisplay();
    display.setTextColor(BLACK, WHITE);
    display.setCursor(16, 10);
    display.setTextSize(1);
    display.print("GAME OVER");
    display.setCursor(21, 30);
    display.setTextSize(1);
    display.print("Score:");
    display.print(Score);
    display.display();
  }
